var page_pipewire_modules =
[
    [ "PipeWire Module: Access", "page_module_access.html", null ],
    [ "PipeWire Module: Adapter", "page_module_adapter.html", null ],
    [ "PipeWire Module: AVB", "page_module_avb.html", null ],
    [ "PipeWire Module: Client Device", "page_module_client_device.html", null ],
    [ "PipeWire Module: Client Node", "page_module_client_node.html", null ],
    [ "PipeWire Module: Combine Stream", "page_module_combine_stream.html", null ],
    [ "PipeWire Module: Echo Cancel", "page_module_echo_cancel.html", null ],
    [ "PipeWire Module: Example Filter", "page_module_example_filter.html", null ],
    [ "PipeWire Module: Example Sink", "page_module_example_sink.html", null ],
    [ "PipeWire Module: Example Source", "page_module_example_source.html", null ],
    [ "PipeWire Module: Fallback Sink", "page_module_fallback_sink.html", null ],
    [ "PipeWire Module: FFADO firewire audio driver", "page_module_ffado_driver.html", null ],
    [ "PipeWire Module: Filter-Chain", "page_module_filter_chain.html", null ],
    [ "PipeWire Module: JACK DBus detect", "page_module_jackdbus_detect.html", null ],
    [ "PipeWire Module: JACK Tunnel", "page_module_jack_tunnel.html", null ],
    [ "PipeWire Module: Link Factory", "page_module_link_factory.html", null ],
    [ "PipeWire Module: Loopback", "page_module_loopback.html", null ],
    [ "PipeWire Module: Metadata", "page_module_metadata.html", null ],
    [ "PipeWire Module: Netjack2 driver", "page_module_netjack2_driver.html", null ],
    [ "PipeWire Module: Netjack2 manager", "page_module_netjack2_manager.html", null ],
    [ "PipeWire Module: Unix Pipe Tunnel", "page_module_pipe_tunnel.html", null ],
    [ "PipeWire Module: Portal", "page_module_portal.html", null ],
    [ "PipeWire Module: Profiler", "page_module_profiler.html", null ],
    [ "PipeWire Module: Protocol Native", "page_module_protocol_native.html", null ],
    [ "PipeWire Module: Protocol Pulse", "page_module_protocol_pulse.html", null ],
    [ "PipeWire Module: Protocol Simple", "page_module_protocol_simple.html", null ],
    [ "PipeWire Module: Pulse Tunnel", "page_module_pulse_tunnel.html", null ],
    [ "PipeWire Module: AirPlay Sink", "page_module_raop_sink.html", null ],
    [ "PipeWire Module: RAOP Discover", "page_module_raop_discover.html", null ],
    [ "PipeWire Module: ROC sink", "page_module_roc_sink.html", null ],
    [ "PipeWire Module: ROC source", "page_module_roc_source.html", null ],
    [ "PipeWire Module: SAP Announce and create RTP streams", "page_module_rtp_sap.html", null ],
    [ "PipeWire Module: RTP sink", "page_module_rtp_sink.html", null ],
    [ "PipeWire Module: RTP source", "page_module_rtp_source.html", null ],
    [ "PipeWire Module: RTP session", "page_module_rtp_session.html", null ],
    [ "PipeWire Module: RT", "page_module_rt.html", null ],
    [ "PipeWire Module: Session Manager", "page_module_session_manager.html", null ],
    [ "PipeWire Module: X11 Bell", "page_module_x11_bell.html", null ],
    [ "PipeWire Module: Zeroconf Discover", "page_module_zeroconf_discover.html", null ]
];